@@ -11,14 +11,13 @@ require 'fog/azurerm/models/storage/sku_tier'
 require 'fog/azurerm/models/storage/kind'
 
 module Fog
-  # Autoload Module for Storage
-  module Storage
-    autoload :AzureRM, File.expand_path('azurerm/storage', __dir__)
-  end
-
   # Main AzureRM fog Provider Module
   module AzureRM
     extend Fog::Provider
+
+    # Autoload Module for Storage
+    autoload :Storage, File.expand_path('azurerm/storage', __dir__)
+
     service(:storage, 'Storage')
   end
 end
