@@ -1,6 +1,6 @@
 module Fog
-  module Storage
-    class AzureRM
+  module AzureRM
+    class Storage
       # This class provides the actual implemention for service calls.
       class Real
         # Get a public blob url from Azure blob storage
@@ -18,8 +18,8 @@ module Fog
       # This class provides the mock implementation for unit tests.
       class Mock
         def get_blob_url(_container_name, _blob_name, options = {})
-          url = 'https://sa.blob.core.windows.net/test_container/test_blob'
-          url.gsub!('https:', 'http:') if options[:scheme] == 'http'
+          url = 'https://mockaccount.blob.core.windows.net/test_container/test_blob'
+          url.sub!('https:', 'http:') if options[:scheme] == 'http'
           url
         end
       end
